"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
var ids_1 = require("./ids");
exports.getWindowDimension = function () {
    var x = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;
    var y = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
    return {
        width: x,
        height: y
    };
};
exports.DeviceWidthObject = (_a = {},
    _a[ids_1.IdDeviceTypeBreakdown.MobileSmall] = { max: 320, min: 0 },
    _a[ids_1.IdDeviceTypeBreakdown.MobileMedium] = { max: 375, min: 321 },
    _a[ids_1.IdDeviceTypeBreakdown.MobileLarge] = { max: 767, min: 376 },
    _a[ids_1.IdDeviceTypeBreakdown.Tablet] = { max: 991, min: 768 },
    _a[ids_1.IdDeviceTypeBreakdown.LaptopSmall] = { max: 1024, min: 992 },
    _a[ids_1.IdDeviceTypeBreakdown.LaptopLarge] = { max: 1440, min: 1025 },
    _a[ids_1.IdDeviceTypeBreakdown.LargerThanLaptop] = { max: 2560, min: 1441 },
    _a[ids_1.IdDeviceTypeBreakdown.LargeScreenMax] = { max: 999999, min: 2561 },
    _a);
exports.getDeviceTypeInfo = function () {
    var _a = exports.getWindowDimension(), width = _a.width, height = _a.height;
    var buildDeviceDetails = {
        deviceType: '',
        deviceTypeVariant: '',
        orientation: ids_1.IdDeviceOrientation.Portrait,
        width: width,
        height: height
    };
    if (height < width) {
        // Orientation is landscape
        buildDeviceDetails.orientation = ids_1.IdDeviceOrientation.Landscape;
        if (height <= ids_1.IdMobileHeight.mobileLandscape_max) {
            // Mobile (landscape)
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Mobile;
            for (var devc in exports.DeviceWidthObject) {
                if (height <= exports.DeviceWidthObject[devc].max && height >= exports.DeviceWidthObject[devc].min) {
                    buildDeviceDetails.deviceTypeVariant = devc;
                    break;
                }
            }
        }
        else if (width <= ids_1.IdDeviceBreakpointsByWidth.tablet_max && width >= ids_1.IdDeviceBreakpointsByWidth.tablet_min) {
            // Tablet (landscape)
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Tablet;
            buildDeviceDetails.deviceTypeVariant = ids_1.IdDeviceTypeBreakdown.Tablet;
        }
        else if (width <= ids_1.IdDeviceBreakpointsByWidth.laptop_max && width >= ids_1.IdDeviceBreakpointsByWidth.laptop_min) {
            // Laptop (landscape)
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Laptop;
            for (var devc in exports.DeviceWidthObject) {
                if (width <= exports.DeviceWidthObject[devc].max && width >= exports.DeviceWidthObject[devc].min) {
                    buildDeviceDetails.deviceTypeVariant = devc;
                    break;
                }
            }
        }
        else {
            // Larger than Laptop (landscape)
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.LargerThanLaptop;
            for (var devc in exports.DeviceWidthObject) {
                if (width <= exports.DeviceWidthObject[devc].max && width >= exports.DeviceWidthObject[devc].min) {
                    buildDeviceDetails.deviceTypeVariant = devc;
                    break;
                }
            }
        }
    }
    else {
        // Orientation is portrait
        buildDeviceDetails.orientation = ids_1.IdDeviceOrientation.Portrait;
        for (var devc in exports.DeviceWidthObject) {
            if (width <= exports.DeviceWidthObject[devc].max && width >= exports.DeviceWidthObject[devc].min) {
                buildDeviceDetails.deviceTypeVariant = devc;
                break;
            }
        }
        if (width <= ids_1.IdDeviceBreakpointsByWidth.laptop_max && width >= ids_1.IdDeviceBreakpointsByWidth.laptop_min) {
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Laptop;
        }
        if (width <= ids_1.IdDeviceBreakpointsByWidth.tablet_max && width >= ids_1.IdDeviceBreakpointsByWidth.tablet_min) {
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Tablet;
        }
        if (width <= ids_1.IdDeviceBreakpointsByWidth.mobile_max) {
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.Mobile;
        }
        if (width > ids_1.IdDeviceBreakpointsByWidth.laptop_max) {
            buildDeviceDetails.deviceType = ids_1.IdDeviceType.LargerThanLaptop;
        }
    }
    return buildDeviceDetails;
};
exports.isMobileDevice = function () {
    var deviceInformation = exports.getDeviceTypeInfo();
    return deviceInformation.deviceType === ids_1.IdDeviceType.Mobile;
};
exports.isTabletDevice = function () {
    var deviceInformation = exports.getDeviceTypeInfo();
    return deviceInformation.deviceType === ids_1.IdDeviceType.Tablet;
};
exports.isLaptopDevice = function () {
    var deviceInformation = exports.getDeviceTypeInfo();
    return deviceInformation.deviceType === ids_1.IdDeviceType.Laptop;
};
exports.isBiggerThanLaptop = function () {
    var deviceInformation = exports.getDeviceTypeInfo();
    return deviceInformation.deviceType === ids_1.IdDeviceType.LargerThanLaptop;
};
//# sourceMappingURL=utilResponsive.js.map